# bridgedbpy
[![Build Status](https://travis-ci.org/ecell/bridgedbpy.svg?branch=master)](https://travis-ci.org/ecell/bridgedbpy)

Python wrapper for the [BridgeDB](https://www.bridgedb.org/swagger/) webservices.
